# iBiz GitLab-CI/CD模板

（技术引用链接）

`GitLab-CI/CD官方文档`[:arrow_upper_right:](https://docs.gitlab.com/ce/ci/yaml/README.html#artifacts)

`iBizSys模型api文档`[:arrow_upper_right:](https://modelapi.ibizlab.cn/)


## 介绍说明
在GitLab-CI/CD之前，iBizSys实现了基于Jenkins的CI/CD。

`GitLab CI`

GitLab CI是GitLab 提供的持续集成服务(从8.0版本之后，GitLab CI已经集成在GitLab中了)，只要在你的仓库根目录下创建一个.gitlab-ci.yml 文件， 并为该项目指派一个Runner，当有合并请求或者Push操作时，你写在.gitlab-ci.yml中的构建脚本就会开始执行。

`GitLab Runner`

GitLab Runner是配合GitLab CI进行构建任务的应用程序，GitLab CI负责yml文件中各种阶段流程的执行，而GitLab Runner就是具体的负责执行每个阶段的脚本执行。

`iBizSys`

iBizSys 是以 `Model Driven Development(MDD)`作为核心理论依据的开发框架，iBizSys从`2009年`诞生至今已经经历数个版本，构建出一套完整的系统构建模型，包含: `DevOps模型`、`文档模型`、`流程模型`、`测试模型`等。 iBizSys 提倡以`模型`作为主要内容的高级别抽象的开发方法，并结合市面上较为流行的技术框架形成技术模板，通过`模型`+`模板`的方式快速构建出一套生产级并且具备`复杂性`和`变更能力`的系统。



## 快速开始

我们将通过搭建一个简单的Demo来阐述 iBizSys 实现 GitLab-CI/CD 的过程，在此之前，我们假设您已经：

- **熟悉GitLab-CI/CD**

- **熟悉FreeMaker**
	
## 建立数据库实例

![produce](https://doc.ibizlab.cn/images/appdb.png)

## 建立微服务平台

![produce](https://doc.ibizlab.cn/images/platform.png)

## 建立微服务平台节点

![produce](https://doc.ibizlab.cn/images/msnode.png)

## 建立部署

![produce](https://doc.ibizlab.cn/images/deploy.png)

## 建立模板

`编写模板方式`

>在线编辑：`iBizSys` 提供模板在线编辑工具，供大家更高效、便捷的编写模板 [查看iBizSys在线编辑工具](http://bbs.ibizlab.cn/)

>离线编辑：由于`iBizSys`的模板是放在`git`仓库中进行托管，用户可在离线环境下编写模板，编辑完成后再将模板上传至`git`中即可。

### 配置模板：

在 ` .gitlab-ci.yml.ftl`中添加构建脚本相关配置
```java
<#ibiztemplate>
TARGET=PSSYSTEM
</#ibiztemplate>
<#if sysrun.getRunMode() == "STARTMSAPI">
<#assign depapi = sysrun.getPSDevSlnMSDepAPI()>
<#assign configId = depapi.getId()>
<#assign config = "api"+depapi.getName()>
<#assign depnode = sysrun.getPSDevSlnMSDepAPI().getPSDCMSPlatformNode()>
<#elseif sysrun.getRunMode() == "STARTMSAPP">
<#assign depapp = sysrun.getPSDevSlnMSDepApp()>
<#assign configId = depapp.getId()>
<#assign config = "app"+depapp.getName()>
<#assign depnode = sysrun.getPSDevSlnMSDepApp().getPSDCMSPlatformNode()>
</#if>
stages:
  - deploy
 
deploysys:
  stage: deploy
  only:
    - master
  script:
    - source /etc/profile 
    - mvn clean
    - mvn package -Pprod
    - echo 'echo "${depnode.getSSHPassword()}"' > apppasswd.sh
    - chmod -R 777 *
    - setsid env SSH_ASKPASS='./apppasswd.sh' DISPLAY='none:0' ssh ${depnode.getSSHUserName()}@${depnode.getSSHIPAddr()} "mkdir -p ${depnode.getWorkshopPath()}/${configId}"
    - setsid env SSH_ASKPASS='./apppasswd.sh' DISPLAY='none:0' scp -r ./${pub.codeName}.jar ${depnode.getSSHUserName()}@${depnode.getSSHIPAddr()}:${depnode.getWorkshopPath()}/${configId}
    - setsid env SSH_ASKPASS='./apppasswd.sh' DISPLAY='none:0' ssh ${depnode.getSSHUserName()}@${depnode.getSSHIPAddr()} "ps -ef | grep '${depnode.getWorkshopPath()}/${configId}'| tr -s ' '|cut -d' ' -f2,8,9  | grep -v grep | grep 'jar' | cut -d' ' -f1|xargs  --no-run-if-empty kill -9"
    - setsid env SSH_ASKPASS='./apppasswd.sh' DISPLAY='none:0' ssh ${depnode.getSSHUserName()}@${depnode.getSSHIPAddr()} "source /etc/profile;source ~/.bash_profile; nohup java -jar ${depnode.getWorkshopPath()}/${configId}/${pub.codeName}.jar  --spring.profiles.active=${config?lower_case} >>${depnode.getWorkshopPath()}/${configId}/${pub.codeName}_${config?lower_case}-`date --date='0 days ago' +%Y-%m-%d`.log 2>&1 &"
    
```

## 发布模板

您在iBizSys模板工具编写模板后，模板处于暂存状态，若您需要在项目中应用该模板，需要发布该模板。

![produce](https://doc.ibizlab.cn/images/templpublish.png)

## 发布模型

发布模型的过程即为从模板仓库中获取最新模板合成模型，生产代码的过程。

![produce](https://doc.ibizlab.cn/images/startup.png)

## 查看最终成果物

### 配置

![produce](https://doc.ibizlab.cn/images/cicdresult.png)

控制台输出：

```
----- selectAll method test ------
DBET(dbetname=这是第一条实体数据, createdate=null, createman=null, dbetid=1, updateman=null, updatedate=null)
DBET(dbetname=这是第二条实体数据, createdate=null, createman=null, dbetid=2, updateman=null, updatedate=null)
DBET(dbetname=这是第三条实体数据, createdate=null, createman=null, dbetid=3, updateman=null, updatedate=null)
DBET(dbetname=这是第四条实体数据, createdate=null, createman=null, dbetid=4, updateman=null, updatedate=null)
DBET(dbetname=这是第五条实体数据, createdate=null, createman=null, dbetid=5, updateman=null, updatedate=null)
 
```

## 小结

通过以上几个简单的步骤，您已经成功搭建一个（SpringBoot+MyBatis-Plus）的项目，实现了对数据表的CURD功能。并且您也成功了搭建了一套属于您个人的技术模板，您可以在以后的任何项目当中，使用您搭建的这套技术模板。

iBizSys可以帮助您快速搭建并使用您所搭建的技术模板来生产您的项目。